/*
 * Copyright 2023, Rainer Noack, Frankfurt am Main, Germany.
 *
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. *
 */
package com.enitsys.sqltools;

import java.io.IOException;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.sql.Statement;
import java.util.Collection;
import java.util.Collections;
import java.util.logging.Level;


public final class SQLcmd extends AbstractSQLTool {
    public static void main(String[] args) {
        main(SQLcmd.class, args);
	}
    private boolean failOnWarning = false;
	SQLcmd(String taskname, String connection, String directory) throws IOException {
        super(taskname, connection, directory);
	}
	public void run() throws SQLException,IOException {
        try (Connection connection=createConnection()) {
            boolean sqlScript=taskProperties.getProperty("sql.script","true").equalsIgnoreCase("true");
            Collection<String> stmts = sqlScript?stmts(null, taskname + ".sql", taskProperties.getProperty("db.productname")):Collections.singletonList(stmt(null, taskname + ".sql"));
            try (DBMSOutput dbmsOutput = new DBMSOutput(connection, 500000)) {
                try (Statement statement = connection.createStatement()) {
                    setCurrentStatement(statement);
                    for (String stmtString: stmts) {
//                        System.out.println("executing: >>>"+stmtString+"<<<");
                        statement.execute(stmtString);
                        if (failOnWarning) {
                            SQLWarning warning = statement.getWarnings();
                            if (warning != null)
                                throw warning;
                        }
                    }
                } finally {
                    setCurrentStatement(null);
                }

                new StreamRedirect(dbmsOutput.fetch(), loggerOutputStream(Level.INFO)).run();
            }

        }
	}

}
